@@ -45,14 +45,11 @@
 
 		#include "gena.h"
 		#include "httpreadwrite.h"
-		#include "parsetools.h"
+		#include "posix_overwrites.h" // IWYU pragma: keep
 		#include "ssdplib.h"
 		#include "statcodes.h"
-		#include "sysdep.h"
-		#include "unixutil.h"
 		#include "upnpapi.h"
 		#include "uuid.h"
-		#include "posix_overwrites.h"
 
 		#define STALE_JOBID (INVALID_JOB_ID - 1)
 
@@ -68,7 +65,7 @@ int genaUnregisterDevice(
 	int ret = 0;
 	struct Handle_Info *handle_info;
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 	if (GetHandleInfo(device_handle, &handle_info) != HND_DEVICE) {
 		UpnpPrintf(UPNP_CRITICAL,
 			GENA,
@@ -81,7 +78,7 @@ int genaUnregisterDevice(
 		freeServiceTable(&handle_info->ServiceTable);
 		ret = UPNP_E_SUCCESS;
 	}
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 	return ret;
 }
@@ -147,17 +144,19 @@ static int GeneratePropertySet(
  */
 static void free_notify_struct(
 	/*! [in] Notify structure. */
-	notify_thread_struct *input)
+	void *input)
 {
-	(*input->reference_count)--;
-	if (*input->reference_count == 0) {
-		free(input->headers);
-		ixmlFreeDOMString(input->propertySet);
-		free(input->servId);
-		free(input->UDN);
-		free(input->reference_count);
+	notify_thread_struct *p = input;
+
+	(*p->reference_count)--;
+	if (*p->reference_count == 0) {
+		free(p->headers);
+		ixmlFreeDOMString(p->propertySet);
+		free(p->servId);
+		free(p->UDN);
+		free(p->reference_count);
 	}
-	free(input);
+	free(p);
 }
 
 /*!
@@ -343,13 +342,13 @@ static void genaNotifyThread(
 	 * there is a lot of notifications, then multiple threads will acquire a
 	 * read lock and the thread which sends the notification will be blocked
 	 * forever on the HandleLock at the end of this function. */
-	/*HandleReadLock(); */
-	HandleLock();
+	/*HandleReadLock(__FILE__, __LINE__); */
+	HandleLock(__FILE__, __LINE__);
 	/* validate context */
 
 	if (GetHandleInfo(in->device_handle, &handle_info) != HND_DEVICE) {
 		free_notify_struct(in);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return;
 	}
 
@@ -359,19 +358,19 @@ static void genaNotifyThread(
 		!(sub = GetSubscriptionSID(in->sid, service)) ||
 		copy_subscription(sub, &sub_copy) != HTTP_SUCCESS) {
 		free_notify_struct(in);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return;
 	}
 
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 	/* send the notify */
 	return_code = genaNotify(in->headers, in->propertySet, &sub_copy);
 	freeSubscription(&sub_copy);
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 	if (GetHandleInfo(in->device_handle, &handle_info) != HND_DEVICE) {
 		free_notify_struct(in);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return;
 	}
 	/* validate context */
@@ -380,7 +379,7 @@ static void genaNotifyThread(
 		!service->active ||
 		!(sub = GetSubscriptionSID(in->sid, service))) {
 		free_notify_struct(in);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return;
 	}
 	sub->ToSendEventKey++;
@@ -410,7 +409,7 @@ static void genaNotifyThread(
 		RemoveSubscriptionSID(in->sid, service);
 	free_notify_struct(in);
 
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 }
 
 /*!
@@ -546,7 +545,7 @@ static int genaInitNotifyCommon(UpnpDevice_Handle device_handle,
 		goto ExitFunction;
 	}
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 
 	if (GetHandleInfo(device_handle, &handle_info) != HND_DEVICE) {
 		line = __LINE__;
@@ -564,7 +563,7 @@ static int genaInitNotifyCommon(UpnpDevice_Handle device_handle,
 		GENA,
 		__FILE__,
 		__LINE__,
-		"FOUND SERVICE IN INIT NOTFY: UDN %s, ServID: %s",
+		"FOUND SERVICE IN INIT NOTFY: UDN %s, ServID: %s\n",
 		UDN,
 		servId);
 
@@ -578,7 +577,7 @@ static int genaInitNotifyCommon(UpnpDevice_Handle device_handle,
 		GENA,
 		__FILE__,
 		__LINE__,
-		"FOUND SUBSCRIPTION IN INIT NOTIFY: SID %s",
+		"FOUND SUBSCRIPTION IN INIT NOTIFY: SID %s\n",
 		sid);
 	sub->active = 1;
 
@@ -645,7 +644,7 @@ ExitFunction:
 		free(reference_count);
 	}
 
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 	UpnpPrintf(UPNP_INFO,
 		GENA,
@@ -690,7 +689,7 @@ int genaInitNotify(UpnpDevice_Handle device_handle,
 		GENA,
 		__FILE__,
 		__LINE__,
-		"GENERATED PROPERTY SET IN INIT NOTIFY: %s",
+		"GENERATED PROPERTY SET IN INIT NOTIFY: %s\n",
 		propertySet);
 
 	ret = genaInitNotifyCommon(
@@ -741,7 +740,7 @@ int genaInitNotifyExt(UpnpDevice_Handle device_handle,
 		GENA,
 		__FILE__,
 		__LINE__,
-		"GENERATED PROPERTY SET IN INIT EXT NOTIFY: %s",
+		"GENERATED PROPERTY SET IN INIT EXT NOTIFY: %s\n",
 		propertySet);
 
 	ret = genaInitNotifyCommon(
@@ -771,6 +770,7 @@ static void maybeDiscardEvents(LinkedList *listp)
 {
 	time_t now = time(0L);
 	notify_thread_struct *ntsp;
+	ThreadPoolJob *p;
 
 	while (ListSize(listp) > 1) {
 		ListNode *node = ListHead(listp);
@@ -783,8 +783,8 @@ static void maybeDiscardEvents(LinkedList *listp)
 			break;
 		}
 
-		ntsp = (notify_thread_struct *)(((ThreadPoolJob *)node->item)
-							->arg);
+		p = (ThreadPoolJob *)node->item;
+		ntsp = (notify_thread_struct *)(p->arg);
 		if (ListSize(listp) > g_UpnpSdkEQMaxLen ||
 			now - ntsp->ctime > g_UpnpSdkEQMaxAge) {
 			free_notify_struct(ntsp);
@@ -853,7 +853,7 @@ static int genaNotifyAllCommon(UpnpDevice_Handle device_handle,
 		goto ExitFunction;
 	}
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 
 	if (GetHandleInfo(device_handle, &handle_info) != HND_DEVICE) {
 		line = __LINE__;
@@ -946,7 +946,7 @@ ExitFunction:
 		free(reference_count);
 	}
 
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 	UpnpPrintf(UPNP_INFO,
 		GENA,
@@ -984,7 +984,7 @@ int genaNotifyAllExt(UpnpDevice_Handle device_handle,
 		GENA,
 		__FILE__,
 		__LINE__,
-		"GENERATED PROPERTY SET IN EXT NOTIFY: %s",
+		"GENERATED PROPERTY SET IN EXT NOTIFY: %s\n",
 		propertySet);
 
 	ret = genaNotifyAllCommon(device_handle, UDN, servId, propertySet);
@@ -1025,7 +1025,7 @@ int genaNotifyAll(UpnpDevice_Handle device_handle,
 		GENA,
 		__FILE__,
 		__LINE__,
-		"GENERATED PROPERTY SET IN EXT NOTIFY: %s",
+		"GENERATED PROPERTY SET IN EXT NOTIFY: %s\n",
 		propertySet);
 
 	ret = genaNotifyAllCommon(device_handle, UDN, servId, propertySet);
@@ -1386,7 +1386,7 @@ void gena_process_subscription_request(SOCKINFO *info, http_message_t *request)
 		"SubscriptionRequest for event URL path: %s\n",
 		event_url_path);
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 
 	if (GetDeviceHandleInfoForPath(event_url_path,
 		    info->foreign_sockaddr.ss_family,
@@ -1395,14 +1395,14 @@ void gena_process_subscription_request(SOCKINFO *info, http_message_t *request)
 		    &service) != HND_DEVICE) {
 		free(event_url_path);
 		error_respond(info, HTTP_INTERNAL_SERVER_ERROR, request);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 	free(event_url_path);
 
 	if (service == NULL || !service->active) {
 		error_respond(info, HTTP_NOT_FOUND, request);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 
@@ -1419,14 +1419,14 @@ void gena_process_subscription_request(SOCKINFO *info, http_message_t *request)
 	if (handle_info->MaxSubscriptions != -1 &&
 		service->TotalSubscriptions >= handle_info->MaxSubscriptions) {
 		error_respond(info, HTTP_INTERNAL_SERVER_ERROR, request);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 	/* generate new subscription */
 	sub = (subscription *)malloc(sizeof(subscription));
 	if (sub == NULL) {
 		error_respond(info, HTTP_INTERNAL_SERVER_ERROR, request);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 	sub->ToSendEventKey = 0;
@@ -1437,7 +1437,7 @@ void gena_process_subscription_request(SOCKINFO *info, http_message_t *request)
 	sub->DeliveryURLs.parsedURLs = NULL;
 	if (ListInit(&sub->outgoing, 0, free) != 0) {
 		error_respond(info, HTTP_INTERNAL_SERVER_ERROR, request);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 
@@ -1445,27 +1445,27 @@ void gena_process_subscription_request(SOCKINFO *info, http_message_t *request)
 	if (httpmsg_find_hdr(request, HDR_CALLBACK, &callback_hdr) == NULL) {
 		error_respond(info, HTTP_PRECONDITION_FAILED, request);
 		freeSubscriptionList(sub);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 	return_code = create_url_list(&callback_hdr, &sub->DeliveryURLs);
 	if (return_code == 0) {
 		error_respond(info, HTTP_PRECONDITION_FAILED, request);
 		freeSubscriptionList(sub);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 	if (return_code == UPNP_E_OUTOF_MEMORY) {
 		error_respond(info, HTTP_INTERNAL_SERVER_ERROR, request);
 		freeSubscriptionList(sub);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 	return_code = gena_validate_delivery_urls(info, &sub->DeliveryURLs);
 	if (return_code != 0) {
 		error_respond(info, HTTP_PRECONDITION_FAILED, request);
 		freeSubscriptionList(sub);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 	/* set the timeout */
@@ -1507,7 +1507,7 @@ void gena_process_subscription_request(SOCKINFO *info, http_message_t *request)
 	if (rc < 0 || (unsigned int)rc >= sizeof(sub->sid) ||
 		(respond_ok(info, time_out, sub, request) != UPNP_E_SUCCESS)) {
 		freeSubscriptionList(sub);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		goto exit_function;
 	}
 	/* add to subscription list */
@@ -1525,7 +1525,7 @@ void gena_process_subscription_request(SOCKINFO *info, http_message_t *request)
 	callback_fun = handle_info->Callback;
 	cookie = handle_info->Cookie;
 
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 
 	/* make call back with request struct */
 	/* in the future should find a way of mainting that the handle */
@@ -1573,7 +1573,7 @@ void gena_process_subscription_renewal_request(
 		return;
 	}
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 
 	if (GetDeviceHandleInfoForPath(event_url_path.buf,
 		    info->foreign_sockaddr.ss_family,
@@ -1582,7 +1582,7 @@ void gena_process_subscription_renewal_request(
 		    &service) != HND_DEVICE) {
 		error_respond(info, HTTP_PRECONDITION_FAILED, request);
 		membuffer_destroy(&event_url_path);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return;
 	}
 	membuffer_destroy(&event_url_path);
@@ -1591,7 +1591,7 @@ void gena_process_subscription_renewal_request(
 	if (service == NULL || !service->active ||
 		((sub = GetSubscriptionSID(sid, service)) == NULL)) {
 		error_respond(info, HTTP_PRECONDITION_FAILED, request);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return;
 	}
 
@@ -1608,7 +1608,7 @@ void gena_process_subscription_renewal_request(
 		service->TotalSubscriptions > handle_info->MaxSubscriptions) {
 		error_respond(info, HTTP_INTERNAL_SERVER_ERROR, request);
 		RemoveSubscriptionSID(sub->sid, service);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return;
 	}
 	/* set the timeout */
@@ -1649,7 +1649,7 @@ void gena_process_subscription_renewal_request(
 		RemoveSubscriptionSID(sub->sid, service);
 	}
 
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 }
 
 void gena_process_unsubscribe_request(SOCKINFO *info, http_message_t *request)
@@ -1686,7 +1686,7 @@ void gena_process_unsubscribe_request(SOCKINFO *info, http_message_t *request)
 		return;
 	}
 
-	HandleLock();
+	HandleLock(__FILE__, __LINE__);
 
 	if (GetDeviceHandleInfoForPath(event_url_path.buf,
 		    info->foreign_sockaddr.ss_family,
@@ -1695,7 +1695,7 @@ void gena_process_unsubscribe_request(SOCKINFO *info, http_message_t *request)
 		    &service) != HND_DEVICE) {
 		error_respond(info, HTTP_PRECONDITION_FAILED, request);
 		membuffer_destroy(&event_url_path);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return;
 	}
 	membuffer_destroy(&event_url_path);
@@ -1704,14 +1704,14 @@ void gena_process_unsubscribe_request(SOCKINFO *info, http_message_t *request)
 	if (service == NULL || !service->active ||
 		GetSubscriptionSID(sid, service) == NULL) {
 		error_respond(info, HTTP_PRECONDITION_FAILED, request);
-		HandleUnlock();
+		HandleUnlock(__FILE__, __LINE__);
 		return;
 	}
 
 	RemoveSubscriptionSID(sid, service);
 	error_respond(info, HTTP_OK, request); /* success */
 
-	HandleUnlock();
+	HandleUnlock(__FILE__, __LINE__);
 }
 
 	#endif /* INCLUDE_DEVICE_APIS */
