@@ -142,7 +142,7 @@ void ssdp_handle_device_request(
 			API,
 			__FILE__,
 			__LINE__,
-			"MX     =  %d\n",
+			"MX          =  %d\n",
 			event.Mx);
 		UpnpPrintf(UPNP_INFO,
 			API,
@@ -210,80 +210,73 @@ static void ProcessSocketError(
 		errorBuffer);
 }
 
-		#define PROCESS_SOCKET_ERROR(file, line, error, func_name) \
+		#define PROCESS_SOCKET_ERROR(file, line, rc, error, func_name) \
 			do { \
 				if (rc == -1) { \
 					ProcessSocketError( \
 						file, line, func_name); \
 					ret = error; \
-					goto end_NewRequestHandler; \
+					goto end_SendToCaller; \
 				} \
 			} while (0)
 
 /*!
- * \brief Works as a request handler which passes the HTTP request string
- * to multicast channel.
+ * \brief Handles the request for one potential target port
  *
  * \return UPNP_E_SUCCESS if successful else appropriate error.
  */
-static int NewRequestHandler(
-	/*! [in] Ip address, to send the reply. */
+static int SendToCaller(
+	/*! [in] Address detail for socket */
+	struct addrinfo *res,
+	/*! [in] Socket address, to send the reply. */
 	struct sockaddr *DestAddr,
 	/*! [in] Number of packet to be sent. */
 	int NumPacket,
-	/*! [in] . */
-	char **RqPacket)
+	/*! [in] Request content */
+	char **RqPacket,
+	/*! [in] Ip address, to send the reply. */
+	struct in_addr *replyAddr)
 {
 	int rc;
 	SOCKET ReplySock;
 	socklen_t socklen = sizeof(struct sockaddr_storage);
 	int Index;
-	struct in_addr replyAddr;
-	struct addrinfo hints, *res;
-	int yes = 1;
+	static const int yes = 1;
 	/* a/c to UPNP Spec */
-	int ttl = 4;
+	static const int ttl = 4;
 		#ifdef UPNP_ENABLE_IPV6
-	int hops = 1;
+	static const int hops = 1;
 		#endif
 	char buf_ntop[INET6_ADDRSTRLEN];
 	int ret = UPNP_E_SUCCESS;
 
-	if (strlen(gIF_IPV4) > (size_t)0 &&
-		!inet_pton(AF_INET, gIF_IPV4, &replyAddr)) {
-		return UPNP_E_INVALID_PARAM;
-	}
-
-	memset(&hints, 0, sizeof(hints));
-	hints.ai_family = DestAddr->sa_family;
-	hints.ai_socktype = SOCK_DGRAM;
-	hints.ai_flags = AI_PASSIVE;
-	if ((rc = getaddrinfo(NULL, SSDP_PORT_STR, &hints, &res)) != 0) {
-		UpnpPrintf(UPNP_INFO,
-			SSDP,
-			__FILE__,
-			__LINE__,
-			"SSDP_LIB: New Request Handler:"
-			"Error in getaddrinfo(): %s\n",
-			gai_strerror(rc));
-		ret = UPNP_E_SOCKET_ERROR;
-		goto end_NewRequestHandlerDontClose;
-	}
 	ReplySock = socket(res->ai_family, res->ai_socktype, res->ai_protocol);
 	if (ReplySock == INVALID_SOCKET) {
 		ProcessSocketError(__FILE__, __LINE__, "socket");
 		ret = UPNP_E_OUTOF_SOCKET;
-		goto end_NewRequestHandlerDontClose;
+		goto end_SendToCallerDontClose;
 	}
 	rc = setsockopt(ReplySock,
 		SOL_SOCKET,
 		SO_REUSEADDR,
 		(OPTION_VALUE_CAST)&yes,
-		sizeof yes);
+		sizeof(yes));
 	PROCESS_SOCKET_ERROR(
-		__FILE__, __LINE__, UPNP_E_SOCKET_ERROR, "setsockopt-1");
-	rc = bind(ReplySock, res->ai_addr, res->ai_addrlen);
-	PROCESS_SOCKET_ERROR(__FILE__, __LINE__, UPNP_E_SOCKET_BIND, "bind");
+		__FILE__, __LINE__, rc, UPNP_E_SOCKET_ERROR, "setsockopt-1");
+		#if (defined(BSD) && !defined(__GNU__)) || \
+			defined(__APPLE__) || defined(__linux__)
+	rc = setsockopt(ReplySock,
+		SOL_SOCKET,
+		SO_REUSEPORT,
+		(OPTION_VALUE_CAST)&yes,
+		sizeof(yes));
+	PROCESS_SOCKET_ERROR(
+		__FILE__, __LINE__, rc, UPNP_E_SOCKET_ERROR, "setsockopt-1x");
+		#endif /* BSD, __APPLE__, __linux__ */
+	ssize_t bindrc = bind(ReplySock, res->ai_addr, res->ai_addrlen);
+	PROCESS_SOCKET_ERROR(
+		__FILE__, __LINE__, bindrc, UPNP_E_SOCKET_BIND, "bind");
+
 	switch (DestAddr->sa_family) {
 	case AF_INET:
 		inet_ntop(AF_INET,
@@ -293,19 +286,21 @@ static int NewRequestHandler(
 		rc = setsockopt(ReplySock,
 			IPPROTO_IP,
 			IP_MULTICAST_IF,
-			(OPTION_VALUE_CAST)&replyAddr,
-			sizeof(replyAddr));
+			(OPTION_VALUE_CAST)replyAddr,
+			sizeof(*replyAddr));
 		PROCESS_SOCKET_ERROR(__FILE__,
 			__LINE__,
+			rc,
 			UPNP_E_SOCKET_ERROR,
 			"setsockopt-2");
 		rc = setsockopt(ReplySock,
 			IPPROTO_IP,
 			IP_MULTICAST_TTL,
 			(OPTION_VALUE_CAST)&ttl,
-			sizeof(int));
+			sizeof(ttl));
 		PROCESS_SOCKET_ERROR(__FILE__,
 			__LINE__,
+			rc,
 			UPNP_E_SOCKET_ERROR,
 			"setsockopt-3");
 		socklen = sizeof(struct sockaddr_in);
@@ -323,6 +318,7 @@ static int NewRequestHandler(
 			sizeof(gIF_INDEX));
 		PROCESS_SOCKET_ERROR(__FILE__,
 			__LINE__,
+			rc,
 			UPNP_E_SOCKET_ERROR,
 			"setsockopt-2");
 		rc = setsockopt(ReplySock,
@@ -332,11 +328,82 @@ static int NewRequestHandler(
 			sizeof(hops));
 		PROCESS_SOCKET_ERROR(__FILE__,
 			__LINE__,
+			rc,
 			UPNP_E_SOCKET_ERROR,
 			"setsockopt-3");
 		break;
 		#endif
-	default:
+	}
+
+	for (Index = 0; Index < NumPacket; Index++) {
+		ssize_t sendrc;
+		UpnpPrintf(UPNP_INFO,
+			SSDP,
+			__FILE__,
+			__LINE__,
+			">>> SSDP SEND to %s >>>\n%s\n",
+			buf_ntop,
+			*(RqPacket + Index));
+		sendrc = sendto(ReplySock,
+			*(RqPacket + Index),
+			strlen(*(RqPacket + Index)),
+			0,
+			DestAddr,
+			socklen);
+		PROCESS_SOCKET_ERROR(__FILE__,
+			__LINE__,
+			sendrc,
+			UPNP_E_SOCKET_WRITE,
+			"sendto");
+	}
+
+end_SendToCaller:
+	UpnpCloseSocket(ReplySock);
+
+end_SendToCallerDontClose:
+
+	return ret;
+}
+
+/*!
+ * \brief Works as a request handler which passes the HTTP request string
+ * to multicast channel.
+ *
+ * \return UPNP_E_SUCCESS if successful else appropriate error.
+ */
+static int NewRequestHandler(
+	/*! [in] Ip address, to send the reply. */
+	struct sockaddr *DestAddr,
+	/*! [in] Number of packet to be sent. */
+	int NumPacket,
+	/*! [in] Request content */
+	char **RqPacket)
+{
+	int rc;
+	struct in_addr replyAddr;
+	struct addrinfo hints, *result, *res;
+	int ret = UPNP_E_SOCKET_ERROR;
+
+	if (strlen(gIF_IPV4) > (size_t)0 &&
+		!inet_pton(AF_INET, gIF_IPV4, &replyAddr)) {
+		return UPNP_E_INVALID_PARAM;
+	}
+
+	memset(&hints, 0, sizeof(hints));
+	hints.ai_family = DestAddr->sa_family;
+	hints.ai_socktype = SOCK_DGRAM;
+	hints.ai_flags = AI_PASSIVE;
+	hints.ai_protocol = 0;
+	hints.ai_canonname = NULL;
+	hints.ai_addr = NULL;
+	hints.ai_next = NULL;
+
+		#ifdef UPNP_ENABLE_IPV6
+	if (DestAddr->sa_family != AF_INET6 && DestAddr->sa_family != AF_INET)
+		#else
+	if (DestAddr->sa_family != AF_INET)
+		#endif
+	{
 		UpnpPrintf(UPNP_CRITICAL,
 			SSDP,
 			__FILE__,
@@ -346,28 +413,32 @@ static int NewRequestHandler(
 		goto end_NewRequestHandler;
 	}
 
-	for (Index = 0; Index < NumPacket; Index++) {
-		ssize_t rc;
+	// getaddrinfo() returns a list of address structures.
+	// Try each address until we successfully bind(2).
+	// If socket(2) (or bind(2)) fails, we (close the socket
+	// and) try the next address
+	if ((rc = getaddrinfo(NULL, SSDP_PORT_STR, &hints, &result)) != 0) {
 		UpnpPrintf(UPNP_INFO,
 			SSDP,
 			__FILE__,
 			__LINE__,
-			">>> SSDP SEND to %s >>>\n%s\n",
-			buf_ntop,
-			*(RqPacket + Index));
-		rc = sendto(ReplySock,
-			*(RqPacket + Index),
-			strlen(*(RqPacket + Index)),
-			0,
-			DestAddr,
-			socklen);
-		PROCESS_SOCKET_ERROR(
-			__FILE__, __LINE__, UPNP_E_SOCKET_WRITE, "sendto");
+			"SSDP_LIB: New Request Handler:"
+			"Error in getaddrinfo(): %s\n",
+			gai_strerror(rc));
+		ret = UPNP_E_SOCKET_ERROR;
+		goto end_NewRequestHandler;
 	}
 
+	for (res = result; res != NULL; res = res->ai_next) {
+		if (SendToCaller(
+			    res, DestAddr, NumPacket, RqPacket, &replyAddr) ==
+			UPNP_E_SUCCESS)
+			ret = UPNP_E_SUCCESS; // one successful send makes
+					      // response successful
+	}
+	freeaddrinfo(result);
+
 end_NewRequestHandler:
-	UpnpCloseSocket(ReplySock);
-end_NewRequestHandlerDontClose:
 
 	return ret;
 }
